[LON-CAPA-cvs] cvs: loncom /cgi createpending.pl
raeburn
raeburn at source.lon-capa.org
Wed Aug 17 10:35:57 EDT 2016
raeburn Wed Aug 17 14:35:57 2016 EDT
Modified files:
/loncom/cgi createpending.pl
Log:
- Include course type for Placement Test containers.
Index: loncom/cgi/createpending.pl
diff -u loncom/cgi/createpending.pl:1.1 loncom/cgi/createpending.pl:1.2
--- loncom/cgi/createpending.pl:1.1 Wed Apr 16 15:36:38 2014
+++ loncom/cgi/createpending.pl Wed Aug 17 14:35:57 2016
@@ -1,10 +1,10 @@
#!/usr/bin/perl
$|=1;
# Script to complete processing of course/community requests
# for unofficial courses, textbook courses and communities
# queued pending validation, once validated.
#
-# $Id: createpending.pl,v 1.1 2014/04/16 15:36:38 raeburn Exp $
+# $Id: createpending.pl,v 1.2 2016/08/17 14:35:57 raeburn Exp $
#
# Copyright Michigan State University Board of Trustees
#
@@ -188,7 +188,7 @@
}
}
if ($field eq 'coursetype') {
- if ($query->param($field) =~ /^(unofficial|community|textbook)$/) {
+ if ($query->param($field) =~ /^(unofficial|community|textbook|placement)$/) {
$params{$field} = $query->param($field);
}
}
@@ -231,7 +231,7 @@
(either query string or POSTed). Keys which will be
used are fields specified in domain configuration
for validation of pending unofficial courses, textbook courses,
- and communities.
+ communities and placement tests.
Returns: $url,$code - If processing of the pending course request succeeds,
a URL is returned which may be used by the requester to access
More information about the LON-CAPA-cvs
@@ -1,10 +1,10 @@
$|=1;
# Script to complete processing of course/community requests
-# for unofficial courses, textbook courses and communities
-# queued pending validation, once validated.
+# for unofficial courses, textbook courses, communities and
+# placement tests queued pending validation, once validated.
#
mailing list